@@ -2,10 +2,10 @@ leaflet_classes_ronds <-
 function(data,fondMaille,fondMailleElargi=NULL,fondSuppl=NULL,idData,varVolume,varRatio,rayonRond=NULL,rapportRond=NULL,methode="kmeans",nbClasses=3,bornes=NULL,stylePalette="defaut",opacityElargi=0.6,colBorderClasses="white",colBorderRondsPos="#303030",colBorderRondsNeg="#303030",epaisseurBorder=1.5,precision=1,emprise="FRM",fondEtranger=NULL,fondChx=NULL,zoomMaille=NULL,map_proxy=NULL)
   {
     options("stringsAsFactors"=FALSE)
-    
+
     # Verification des parametres
     leafletVerifParamClassesRonds(data,fondMaille,fondMailleElargi,fondSuppl,idData,varVolume,varRatio,rayonRond,rapportRond,methode,nbClasses,bornes,stylePalette,opacityElargi,colBorderClasses,colBorderRondsPos,colBorderRondsNeg,epaisseurBorder,precision,emprise,fondEtranger,fondChx,map_proxy)
-    
+
     if(!is.null(fondChx))
     {
       centroid <- "chx"
@@ -13,42 +13,49 @@ function(data,fondMaille,fondMailleElargi=NULL,fondSuppl=NULL,idData,varVolume,v
     {
       centroid <- "centroid"
     }
-    
+
     names(data)[names(data)==idData] <- "CODE"
     names(fondMaille)[1] <- "CODE"
     names(fondMaille)[2] <- "LIBELLE"
-    if(!is.null(fondMailleElargi)) 
+    if(!is.null(fondMailleElargi))
     {
       names(fondMailleElargi)[1] <- "CODE"
       names(fondMailleElargi)[2] <- "LIBELLE"
       fondMailleElargi$LIBELLE<-iconv(fondMailleElargi$LIBELLE,"latin1","utf8")
     }
-    if(!is.null(fondSuppl)) 
+    if(!is.null(fondSuppl))
     {
       names(fondSuppl)[1] <- "CODE"
       names(fondSuppl)[2] <- "LIBELLE"
       fondSuppl$LIBELLE<-iconv(fondSuppl$LIBELLE,"latin1","utf8")
     }
     epsg_etranger <- NULL
-    if(!is.null(fondEtranger)) 
+    if(!is.null(fondEtranger))
     {
       names(fondEtranger)[1] <- "CODE"
       names(fondEtranger)[2] <- "LIBELLE"
       fondEtranger$LIBELLE<-iconv(fondEtranger$LIBELLE,"latin1","utf8")
-      
-      epsg_etranger <- st_crs(fondEtranger)$epsg
+
+      if(substr(st_crs(fondEtranger)[1]$input,1,5) == "EPSG:")
+      {
+        epsg_etranger <- substr(st_crs(fondEtranger)[1]$input,6,9)
+      }else
+      {
+        epsg_etranger <- st_crs(fondEtranger)[1]$input
+      }
+
       if(is.na(epsg_etranger) | epsg_etranger=="4326")
       {
         epsg_etranger <- "3395" # Mercator
       }
     }
-    if(!is.null(fondChx)) 
+    if(!is.null(fondChx))
     {
       names(fondChx)[1] <- "CODE"
     }
-    
+
     fondMaille$LIBELLE<-iconv(fondMaille$LIBELLE,"latin1","utf8")
-    
+
     if(!is.null(map_proxy))
     {
       if(any(class(map_proxy) %in% "leaflet_proxy")) # Contexte shiny/proxy
@@ -59,7 +66,7 @@ function(data,fondMaille,fondMailleElargi=NULL,fondSuppl=NULL,idData,varVolume,v
         clearGroup(map_proxy, group = "carte_classes_elargi")
       }
     }
-    
+
     if(is.null(fondMailleElargi))
     {
       elargi <- FALSE
@@ -67,7 +74,7 @@ function(data,fondMaille,fondMailleElargi=NULL,fondSuppl=NULL,idData,varVolume,v
     {
       elargi <- TRUE
     }
-    
+
     code_epsg <- switch(emprise,
                         "FRM"="2154",# Lambert 93
                         "971"="32620",# UTM 20 N
@@ -76,14 +83,14 @@ function(data,fondMaille,fondMailleElargi=NULL,fondSuppl=NULL,idData,varVolume,v
                         "974"="2975",# UTM 40 S
                         "976"="4471",# UTM 38 S
                         "999"=epsg_etranger)
-    
+
     # Calcul du rayon du rond max
-    
+
     #Aire totale du territoire d'etude
     aire_territoire <- as.numeric(sum(st_area(fondMaille[fondMaille$CODE %in% data[,"CODE"],]))) #Superficie du territoire
     #valeur max de la serie de donnees
     suppressWarnings(max_var <- max(abs(data[data[,"CODE"] %in% fondMaille$CODE,varVolume]), na.rm = TRUE))
-    
+
     serie <- data[data[,"CODE"] %in% fondMaille$CODE,varVolume]
     serie <- serie[!is.na(serie)]
     #on ramene la serie a un quotient fonction de la valeur max
@@ -94,7 +101,7 @@ function(data,fondMaille,fondMailleElargi=NULL,fondSuppl=NULL,idData,varVolume,v
     max_surface_rond <- (aire_territoire/(7*somme_quotient))
     #calcul du rayon max du rond le plus grand
     max_rayon_metres <- sqrt(max_surface_rond/pi)
-    
+
     if(!is.null(rayonRond))
     {
       if(!is.na(rayonRond))
@@ -114,21 +121,21 @@ function(data,fondMaille,fondMailleElargi=NULL,fondSuppl=NULL,idData,varVolume,v
         rayonRond <- max_rayon_metres
       }
     }
-    
+
     if(is.null(rayonRond) & is.null(rapportRond))
     {
       rayonRond <- max_rayon_metres/1.25
     }
-    
+
     if(is.null(rayonRond) & !is.null(rapportRond)) #Calcul du rayon a partir du rapport
     {
       rayonRond <- round(sqrt((rapportRond*max_var)/pi),0)
     }
-    
+
     # Analyse ronds
-    
+
     analyse <- k_ronds(fondMaille,fondMailleElargi,names(fondMaille)[1],data,"CODE",varVolume,elargi,centroid,fondChx)
-    
+
     if(is.null(analyse))
     {
       if(!is.null(map_proxy))
@@ -140,9 +147,9 @@ function(data,fondMaille,fondMailleElargi=NULL,fondSuppl=NULL,idData,varVolume,v
         stop(simpleError("La maille ne correspond pas au niveau geographique du fichier de donnees. Veuillez svp choisir une maille adaptee ou modifier le fichier de donnees"))
       }
     }
-    
+
     analyse$donnees[,varRatio] <- round(analyse$donnees[,varRatio],precision)
-    
+
     analyse$donnees[,"TXT1"] <- paste0("<b> <font color=#2B3E50>",format(analyse$donnees$save, big.mark=" ",decimal.mark=",",nsmall=0),"</font></b>")
     analyse$donnees[,"TXT2"] <- paste0("<b> <font color=#2B3E50>",format(analyse$donnees[,varRatio], big.mark=" ",decimal.mark=",",nsmall=0),"</font></b>")
     if(elargi)
@@ -150,9 +157,9 @@ function(data,fondMaille,fondMailleElargi=NULL,fondSuppl=NULL,idData,varVolume,v
       analyse$donnees_elargi[,"TXT1"] <- paste0("<b> <font color=#2B3E50>",format(analyse$donnees_elargi$save, big.mark=" ",decimal.mark=",",nsmall=0),"</font></b>")
       analyse$donnees_elargi[,"TXT2"] <- paste0("<b> <font color=#2B3E50>",format(analyse$donnees_elargi[,varRatio], big.mark=" ",decimal.mark=",",nsmall=0),"</font></b>")
     }
-    
+
     analyse_WGS84 <- st_transform(analyse$analyse_points,"+init=epsg:4326 +proj=longlat +ellps=WGS84")
-    
+
     max <- max(analyse$donnees[,varRatio])
     min <- min(analyse$donnees[,varRatio])
     if(elargi)
@@ -160,11 +167,11 @@ function(data,fondMaille,fondMailleElargi=NULL,fondSuppl=NULL,idData,varVolume,v
       max <- max(analyse$donnees_elargi[,varRatio])
       min <- min(analyse$donnees_elargi[,varRatio])
     }
-    
+
     if(is.null(bornes))
     {
       suppressWarnings(test_bornes_analyse <- try(classIntervals(as.numeric(analyse$donnees[,varRatio]),nbClasses,style=methode,rtimes=10,intervalClosure="left"),silent=TRUE))
-      
+
       if(!class(test_bornes_analyse) %in% "try-error")
       {
         suppressWarnings(bornes_analyse <- classIntervals(as.numeric(analyse$donnees[,varRatio]),nbClasses,style=methode,rtimes=10,intervalClosure="left"))
@@ -179,9 +186,9 @@ function(data,fondMaille,fondMailleElargi=NULL,fondSuppl=NULL,idData,varVolume,v
           stop(simpleError("Le nombre de classes n'est pas adapte a l'analyse."))
         }
       }
-      
+
       suppressWarnings(test_calcul_bornes <- try(calcul_bornes(analyse$donnees,bornes_analyse,varRatio,nbClasses,methode,stylePalette),silent=TRUE))
-      
+
       if(!class(test_calcul_bornes) %in% "try-error")
       {
         carac_bornes <- calcul_bornes(analyse$donnees,bornes_analyse,varRatio,nbClasses,methode,stylePalette)
@@ -196,7 +203,7 @@ function(data,fondMaille,fondMailleElargi=NULL,fondSuppl=NULL,idData,varVolume,v
           stop(simpleError("La maille ne correspond pas au niveau geographique du fichier de donnees. Veuillez svp choisir une maille adaptee ou modifier le fichier de donnees"))
         }
       }
-      
+
       bornes <- carac_bornes[[1]]
       bornes[1] <- max(as.numeric(analyse$donnees[,varRatio]))
       bornes_sansext <- bornes[-1]
@@ -205,19 +212,22 @@ function(data,fondMaille,fondMailleElargi=NULL,fondSuppl=NULL,idData,varVolume,v
       bornes <- unique(c(max,bornes_sansext,min))
       bornes <- round(bornes,precision)
       pal_classes <- carac_bornes[[2]]
-      
+
     }else
     {
       bornes_sansext <- sort(bornes, decreasing = TRUE)
       bornes <- unique(c(max,bornes_sansext,min))
       bornes <- round(bornes,precision)
-      
+
       pal_classes_pos <- recup_palette(stylePalette)[[1]]
       pal_classes_neg <- recup_palette(stylePalette)[[2]]
-      
+
+      nb_col_pos <- length(pal_classes_pos)
+
       if(min<0 & max>=0) # Si - et +
       {
-        pal_classes_pos <- pal_classes_pos[(7-length(bornes[bornes>0])+1):7]
+        nb_col <- length(pal_classes_pos)
+        pal_classes_pos <- pal_classes_pos[(nb_col_pos-length(bornes[bornes>0])+1):nb_col_pos]
         pal_classes_neg <- pal_classes_neg[1:length(bornes[bornes<0])]
         pal_classes <- c(pal_classes_pos,pal_classes_neg)
       }
@@ -228,7 +238,7 @@ function(data,fondMaille,fondMailleElargi=NULL,fondSuppl=NULL,idData,varVolume,v
           pal_classes <- pal_classes_pos
         }else
         {
-          pal_classes <- pal_classes_pos[-c(1:(7-length(bornes)+1))] # On enleve les couleurs fonces inutiles
+          pal_classes <- pal_classes_pos[-c(1:(nb_col_pos-length(bornes)+1))] # On enleve les couleurs fonces inutiles
         }
       }
       if(max<0) # Si -
@@ -242,13 +252,13 @@ function(data,fondMaille,fondMailleElargi=NULL,fondSuppl=NULL,idData,varVolume,v
         }
       }
     }
-    
+
     pal_classes[is.na(pal_classes)] <- "grey"
-    
+
     palette<-colorBin(palette=rev(pal_classes), domain=0:100, bins=bornes, na.color="grey")
-    
+
     # Fonds habillages
-    
+
     if(emprise=="FRM")
     {
       fond_pays <- st_transform(sf_paysm(),"+init=epsg:4326 +proj=longlat +ellps=WGS84")
@@ -285,15 +295,15 @@ function(data,fondMaille,fondMailleElargi=NULL,fondSuppl=NULL,idData,varVolume,v
       fond_etranger <- st_transform(fondEtranger,"+init=epsg:4326 +proj=longlat +ellps=WGS84")
       fond_pays <- fond_etranger
     }else{}
-    
+
     maille_WGS84 <- st_transform(fondMaille,"+init=epsg:4326 +proj=longlat +ellps=WGS84")
-    
+
     if(elargi)
     {
       analyse_WGS84_elargi <- st_transform(analyse$analyse_points_elargi,"+init=epsg:4326 +proj=longlat +ellps=WGS84")
       maille_WGS84_elargi <- st_transform(fondMailleElargi,"+init=epsg:4326 +proj=longlat +ellps=WGS84")
     }
-    
+
     if(!is.null(zoomMaille))
     {
       zoom_maille_WGS84 <- maille_WGS84[maille_WGS84$CODE %in% zoomMaille,]
@@ -308,14 +318,14 @@ function(data,fondMaille,fondMailleElargi=NULL,fondSuppl=NULL,idData,varVolume,v
     {
       list_bbox <- list(c(st_bbox(maille_WGS84)[1],st_bbox(maille_WGS84)[3]),c(st_bbox(maille_WGS84)[2],st_bbox(maille_WGS84)[4]))
     }
-    
+
     if(!is.null(fondSuppl))
     {
       fond_territoire <- st_transform(fondSuppl,"+init=epsg:4326 +proj=longlat +ellps=WGS84")
     }
-    
+
     # Construction de la map par defaut
-    
+
     if(is.null(map_proxy) | (!is.null(map_proxy) & class(map_proxy)=="character"))
     {
       map <- leaflet(padding = 0,
@@ -323,17 +333,17 @@ function(data,fondMaille,fondMailleElargi=NULL,fondSuppl=NULL,idData,varVolume,v
                        preferCanvas = TRUE,
                        transition = 2
                      )) %>%
-        
+
         setMapWidgetStyle(list(background = "#AFC9E0")) %>%
-        
+
         addTiles_insee(attribution = paste0("<a href=\"http://www.insee.fr\">OCEANIS - \u00A9 IGN - INSEE ",format(Sys.time(), format = "%Y"),"</a>")) %>%
-        
+
         fitBounds(lng1 = min(list_bbox[[1]]),
                   lat1 = min(list_bbox[[2]]),
                   lng2 = max(list_bbox[[1]]),
                   lat2 = max(list_bbox[[2]])
         ) %>%
-        
+
         # Pour gerer l'ordre des calques
         addMapPane(name = "fond_pays", zIndex = 401) %>%
         addMapPane(name = "fond_france", zIndex = 402) %>%
@@ -344,14 +354,14 @@ function(data,fondMaille,fondMailleElargi=NULL,fondSuppl=NULL,idData,varVolume,v
         addMapPane(name = "fond_ronds_elargi", zIndex = 407) %>%
         addMapPane(name = "fond_ronds", zIndex = 408) %>%
         addMapPane(name = "fond_legende", zIndex = 409) %>%
-      
+
         # On ajoute une barre d'echelle
         addScaleBar(position = 'bottomright',
                     options = scaleBarOptions(metric = TRUE, imperial = FALSE)
         )
-      
+
       # AFFICHAGE DES FONDS D'HABILLAGE
-      
+
       if(emprise %in% c("FRM","973")) # France metro ou Guyane
       {
         map <- addPolygons(map = map, data = fond_pays[,"LIBGEO"], opacity = 1,
@@ -363,7 +373,7 @@ function(data,fondMaille,fondMailleElargi=NULL,fondSuppl=NULL,idData,varVolume,v
                            group = "carte_classes_ronds_init",
                            layerId = list(fond_pays=fond_pays,code_epsg=code_epsg,nom_fond="fond_pays")
         )
-        
+
         map <- addPolygons(map = map, data = fond_france[,"LIBGEO"], opacity = 1,
                            stroke = TRUE, color = "black",
                            weight = 1.5,
@@ -396,9 +406,9 @@ function(data,fondMaille,fondMailleElargi=NULL,fondSuppl=NULL,idData,varVolume,v
                            layerId = list(fond_etranger=fond_etranger,code_epsg=code_epsg,nom_fond="fond_etranger")
         )
       }
-      
+
       # AFFICHAGE DU FOND TERRITOIRE
-      
+
       if(!is.null(fondSuppl))
       {
         map <- addPolygons(map = map, data = fond_territoire,
@@ -415,17 +425,17 @@ function(data,fondMaille,fondMailleElargi=NULL,fondSuppl=NULL,idData,varVolume,v
     {
       map <- map_proxy
     }
-    
+
     if(!is.null(fondMailleElargi))
     {
       # AFFICHAGE DE LA MAILLE ET DE L'ANALYSE EN CLASSES ELARGIE
-      
+
       analyse_maille_classe_elargi <- analyse$donnees_elargi[rev(order(analyse$donnees_elargi[,varRatio])),varRatio]
-      
+
       analyse_maille_elargi <- merge(maille_WGS84_elargi[,c("CODE","geometry")],analyse$donnees_elargi,by="CODE")
       analyse_maille_elargi <- analyse_maille_elargi[rev(order(as.data.frame(analyse_maille_elargi)[,varRatio])),c("CODE","LIBELLE",varRatio,"TXT1","TXT2","geometry")]
       analyse_maille_elargi <- st_sf(analyse_maille_elargi,stringsAsFactors = FALSE)
-      
+
       map <- addPolygons(map = map, data = analyse_maille_elargi, opacity = opacityElargi,
                          stroke = TRUE, color = colBorderClasses, weight = 1,
                          options = pathOptions(pane = "fond_classes_elargi", clickable = T),
@@ -437,15 +447,15 @@ function(data,fondMaille,fondMailleElargi=NULL,fondSuppl=NULL,idData,varVolume,v
                          layerId = list(analyse_maille_elargi=analyse_maille_elargi,analyse_maille_classe_elargi=analyse_maille_classe_elargi,code_epsg=code_epsg,emprise=emprise,nom_fond="fond_maille_elargi_carte",bornes=bornes,var_ratio=varRatio,precision=precision,style=stylePalette,palette=pal_classes,col_border_classes=colBorderClasses)
       )
     }
-    
+
     # AFFICHAGE DE LA MAILLE ET DE L'ANALYSE EN CLASSES
-    
+
     analyse_maille_classe <- analyse$donnees[rev(order(analyse$donnees[,varRatio])),varRatio]
-    
+
     analyse_maille <- merge(maille_WGS84[,c("CODE","geometry")],analyse$donnees,by="CODE")
     analyse_maille <- analyse_maille[rev(order(as.data.frame(analyse_maille)[,varRatio])),c("CODE","LIBELLE",varRatio,"TXT1","TXT2","geometry")]
     analyse_maille <- st_sf(analyse_maille,stringsAsFactors = FALSE)
-    
+
     map <- addPolygons(map = map, data = analyse_maille, opacity = 1,
                        stroke = TRUE, color = colBorderClasses, weight = 1,
                        options = pathOptions(pane = "fond_classes", clickable = T),
@@ -456,11 +466,11 @@ function(data,fondMaille,fondMailleElargi=NULL,fondSuppl=NULL,idData,varVolume,v
                        group = "carte_classes",
                        layerId = list(analyse_maille=analyse_maille,analyse_maille_classe=analyse_maille_classe,code_epsg=code_epsg,emprise=emprise,nom_fond="fond_maille_carte",bornes=bornes,var_ratio=varRatio,precision=precision,style=stylePalette,palette=pal_classes,col_border_classes=colBorderClasses)
     )
-    
+
     if(!is.null(fondMailleElargi))
     {
       # AFFICHAGE DE L'ANALYSE EN RONDS ELARGIE
-      
+
       map <- addCircles(map = map,
                         lng = st_coordinates(analyse_WGS84_elargi)[,1],
                         lat = st_coordinates(analyse_WGS84_elargi)[,2],
@@ -475,9 +485,9 @@ function(data,fondMaille,fondMailleElargi=NULL,fondSuppl=NULL,idData,varVolume,v
                         layerId = list(analyse_WGS84_elargi=analyse_WGS84_elargi,analyse=analyse,code_epsg=code_epsg,emprise=emprise,nom_fond="fond_classes_ronds_elargi_carte",max_var=max_var,var_volume=varVolume,rayonRond=rayonRond,col_border_ronds_pos=colBorderRondsPos,col_border_ronds_neg=colBorderRondsNeg,epaisseurBorder=epaisseurBorder)
       )
     }
-    
+
     # AFFICHAGE DE L'ANALYSE EN RONDS
-    
+
     map <- addCircles(map = map,
                       lng = st_coordinates(analyse_WGS84)[,1],
                       lat = st_coordinates(analyse_WGS84)[,2],
@@ -491,6 +501,6 @@ function(data,fondMaille,fondMailleElargi=NULL,fondSuppl=NULL,idData,varVolume,v
                       group = "carte_ronds",
                       layerId = list(analyse_WGS84=analyse_WGS84,analyse=analyse,code_epsg=code_epsg,emprise=emprise,nom_fond="fond_classes_ronds_carte",max_var=max_var,var_volume=varVolume,rayonRond=rayonRond,col_border_ronds_pos=colBorderRondsPos,col_border_ronds_neg=colBorderRondsNeg,epaisseurBorder=epaisseurBorder)
     )
-    
+
     return(map)
   }
