@@ -2,35 +2,42 @@ leaflet_saphirs <-
 function(data,fondMaille,typeMaille,fondSuppl=NULL,idDataDepart,idDataArrivee,varFlux,largeurFlecheMax=NULL,direction="Ent",filtreVol=0,colEntree="#CD853F",colSortie="#6495ED",colBorder="#303030",emprise="FRM",fondEtranger=NULL,zoomMaille=NULL,map_proxy=NULL)
   {
     options("stringsAsFactors"=FALSE)
-    
+
     # Verification des parametres
     leafletVerifParamSaphirs(data,fondMaille,typeMaille,fondSuppl,idDataDepart,idDataArrivee,varFlux,largeurFlecheMax,direction,filtreVol,colEntree,colSortie,colBorder,emprise,fondEtranger,map_proxy)
-    
+
     names(data)[names(data)==idDataDepart] <- "CODE1"
     names(data)[names(data)==idDataArrivee] <- "CODE2"
     names(fondMaille)[1] <- "CODE"
     names(fondMaille)[2] <- "LIBELLE"
-    if(!is.null(fondSuppl)) 
+    if(!is.null(fondSuppl))
     {
       names(fondSuppl)[1] <- "CODE"
       names(fondSuppl)[2] <- "LIBELLE"
       fondSuppl$LIBELLE<-iconv(fondSuppl$LIBELLE,"latin1","utf8")
     }
     epsg_etranger <- NULL
-    if(!is.null(fondEtranger)) 
+    if(!is.null(fondEtranger))
     {
       names(fondEtranger)[1] <- "CODE"
       names(fondEtranger)[2] <- "LIBELLE"
       fondEtranger$LIBELLE<-iconv(fondEtranger$LIBELLE,"latin1","utf8")
-      
-      epsg_etranger <- st_crs(fondEtranger)$epsg
+
+      if(substr(st_crs(fondEtranger)[1]$input,1,5) == "EPSG:")
+      {
+        epsg_etranger <- substr(st_crs(fondEtranger)[1]$input,6,9)
+      }else
+      {
+        epsg_etranger <- st_crs(fondEtranger)[1]$input
+      }
+
       if(is.na(epsg_etranger) | epsg_etranger=="4326")
       {
         epsg_etranger <- "3395" # Mercator
       }
     }
     fondMaille$LIBELLE<-iconv(fondMaille$LIBELLE,"latin1","utf8")
-    
+
     if(!is.null(map_proxy))
     {
       if(any(class(map_proxy) %in% "leaflet_proxy"))
@@ -38,7 +45,7 @@ function(data,fondMaille,typeMaille,fondSuppl=NULL,idDataDepart,idDataArrivee,va
         clearGroup(map_proxy, group = "carte_saphirs")
       }
     }
-    
+
     code_epsg <- switch(emprise,
                         "FRM"="2154",# Lambert 93
                         "971"="32620",# UTM 20 N
@@ -47,7 +54,7 @@ function(data,fondMaille,typeMaille,fondSuppl=NULL,idDataDepart,idDataArrivee,va
                         "974"="2975",# UTM 40 S
                         "976"="4471",# UTM 38 S
                         "999"=epsg_etranger)
-    
+
     # Analyse
     if(is.null(largeurFlecheMax))
     {
@@ -60,18 +67,18 @@ function(data,fondMaille,typeMaille,fondSuppl=NULL,idDataDepart,idDataArrivee,va
       if (typeMaille=="EPCI") largeurFlecheMax<-4
       if (typeMaille=="COM") largeurFlecheMax<-2
     }
-    
+
     if(typeMaille=="REG") longueur<-100000
     if(typeMaille=="DEP") longueur<-30000
     if(!typeMaille %in% c("REG","DEP")) longueur<-10000
-    
+
     data <- data[data$CODE1!=data$CODE2,]
     analyse<-k_saphir(fondMaille,names(fondMaille)[1],data,"CODE1","CODE2",varFlux,largeurFlecheMax*1000,longueur,direction)
-    
+
     analyse_WGS84 <- st_transform(analyse[[1]],"+init=epsg:4326 +proj=longlat +ellps=WGS84")
-    
+
     # Fonds habillages
-    
+
     if(emprise=="FRM")
     {
       fond_pays <- st_transform(sf_paysm(),"+init=epsg:4326 +proj=longlat +ellps=WGS84")
@@ -108,9 +115,9 @@ function(data,fondMaille,typeMaille,fondSuppl=NULL,idDataDepart,idDataArrivee,va
       fond_etranger <- st_transform(fondEtranger,"+init=epsg:4326 +proj=longlat +ellps=WGS84")
       fond_pays <- fond_etranger
     }else{}
-    
+
     maille_WGS84 <- st_transform(fondMaille,"+init=epsg:4326 +proj=longlat +ellps=WGS84")
-    
+
     if(!is.null(zoomMaille))
     {
       zoom_maille_WGS84 <- maille_WGS84[maille_WGS84$CODE %in% zoomMaille,]
@@ -125,12 +132,12 @@ function(data,fondMaille,typeMaille,fondSuppl=NULL,idDataDepart,idDataArrivee,va
     {
       list_bbox <- list(c(st_bbox(maille_WGS84)[1],st_bbox(maille_WGS84)[3]),c(st_bbox(maille_WGS84)[2],st_bbox(maille_WGS84)[4]))
     }
-    
+
     if(!is.null(fondSuppl))
     {
       fond_territoire <- st_transform(fondSuppl,"+init=epsg:4326 +proj=longlat +ellps=WGS84")
     }
-    
+
     if(direction!="Sol")
     {
       analyse_WGS84 <- analyse_WGS84[abs(as.data.frame(analyse_WGS84)[,varFlux])>=100,]
@@ -140,10 +147,10 @@ function(data,fondMaille,typeMaille,fondSuppl=NULL,idDataDepart,idDataArrivee,va
     {
       donnees <- as.data.frame(analyse_WGS84)
     }
-    
+
     coord_fleche_max_pl <- st_coordinates(analyse[[1]][abs(data.frame(analyse[[1]])[,varFlux])==max(abs(donnees[,varFlux])),])
     large_pl <- max(st_distance(st_sfc(st_point(c(coord_fleche_max_pl[2,1],coord_fleche_max_pl[2,2])),st_point(c(coord_fleche_max_pl[6,1],coord_fleche_max_pl[6,2])))))
-    
+
     # Construction de la map par defaut
     if(is.null(map_proxy) | (!is.null(map_proxy) & class(map_proxy)=="character"))
     {
@@ -152,17 +159,17 @@ function(data,fondMaille,typeMaille,fondSuppl=NULL,idDataDepart,idDataArrivee,va
                        preferCanvas = TRUE,
                        transition = 2
                      )) %>%
-        
+
         setMapWidgetStyle(list(background = "#AFC9E0")) %>%
-        
+
         addTiles_insee(attribution = paste0("<a href=\"http://www.insee.fr\">OCEANIS - \u00A9 IGN - INSEE ",format(Sys.time(), format = "%Y"),"</a>")) %>%
-        
+
         fitBounds(lng1 = min(list_bbox[[1]]),
                   lat1 = min(list_bbox[[2]]),
                   lng2 = max(list_bbox[[1]]),
                   lat2 = max(list_bbox[[2]])
         ) %>%
-        
+
         # Pour gerer l'ordre des calques
         addMapPane(name = "fond_pays", zIndex = 401) %>%
         addMapPane(name = "fond_france", zIndex = 402) %>%
@@ -171,12 +178,12 @@ function(data,fondMaille,typeMaille,fondSuppl=NULL,idDataDepart,idDataArrivee,va
         addMapPane(name = "fond_maille", zIndex = 405) %>%
         addMapPane(name = "fond_saphirs", zIndex = 406) %>%
         addMapPane(name = "fond_legende", zIndex = 407) %>%
-        
+
         # On ajoute une barre d'echelle
         addScaleBar(position = 'bottomright',
                     options = scaleBarOptions(metric = TRUE, imperial = FALSE)
         )
-      
+
       # AFFICHAGE DES FONDS D'HABILLAGE
       if(emprise %in% c("FRM","973")) # France metro ou Guyane
       {
@@ -189,7 +196,7 @@ function(data,fondMaille,typeMaille,fondSuppl=NULL,idDataDepart,idDataArrivee,va
                            group = "carte_saphirs_init",
                            layerId = list(fond_pays=fond_pays,code_epsg=code_epsg,nom_fond="fond_pays")
         )
-        
+
         map <- addPolygons(map = map, data = fond_france[,"LIBGEO"], opacity = 1,
                            stroke = TRUE, color = "black",
                            weight = 1.5,
@@ -222,9 +229,9 @@ function(data,fondMaille,typeMaille,fondSuppl=NULL,idDataDepart,idDataArrivee,va
                            layerId = list(fond_etranger=fond_etranger,code_epsg=code_epsg,nom_fond="fond_etranger")
         )
       }
-      
+
       # AFFICHAGE DU FOND TERRITOIRE
-      
+
       if(!is.null(fondSuppl))
       {
         map <- addPolygons(map = map, data = fond_territoire,
@@ -237,9 +244,9 @@ function(data,fondMaille,typeMaille,fondSuppl=NULL,idDataDepart,idDataArrivee,va
                            layerId = list(fond_territoire=fond_territoire,code_epsg=code_epsg,nom_fond="fond_territoire")
         )
       }
-      
+
       # AFFICHAGE DE LA MAILLE
-      
+
       map <- addPolygons(map = map, data = maille_WGS84, opacity = 1,
                          stroke = TRUE, color = "grey",
                          weight = 0.5,
@@ -253,9 +260,9 @@ function(data,fondMaille,typeMaille,fondSuppl=NULL,idDataDepart,idDataArrivee,va
     {
       map <- map_proxy
     }
-    
+
     # AFFICHAGE DE L'ANALYSE
-    
+
     if(max(donnees[,varFlux])<0) colEntree <- NULL
     if(min(donnees[,varFlux])>=0) colSortie <- NULL
 
@@ -270,6 +277,6 @@ function(data,fondMaille,typeMaille,fondSuppl=NULL,idDataDepart,idDataArrivee,va
                        group = "carte_saphirs",
                        layerId = list(analyse_WGS84=analyse_WGS84,donnees=donnees,colEntree=colEntree,colSortie=colSortie,code_epsg=code_epsg,emprise=emprise,nom_fond="fond_flux",var_flux=varFlux,max_var=max(abs(donnees[,varFlux])),largeur=largeurFlecheMax,distance=large_pl)
     )
-    
+
     return(map)
   }
